:orphan:

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _releasenotes:

FileBrowser 3.8.2 Release Notes
===============================

* Added a Azure Blob Storage mixin to work with django-storages.
  For details see the source file
  https://github.com/christianwgd/django-filebrowser-no-grappelli/blob/master/filebrowser/storage.py

FileBrowser 3.8.1 Release Notes
===============================

Forked from https://github.com/smacker/django-filebrowser-no-grappelli

* Fixed an layout issue with Django > 3.1.1 where django admin changelist changed to flex design.
* TinyMCE updated to version 5.4
* Dropped support for Django < 3 and python < 3.6
